# bs-processors

**NOTE:** THIS SOFTWARE IS **EARLY PRE ALPHA** AND IT IS NOT READY FOR GENERAL USE

Library with utilities for easy html & xml processing using 
[BeautifulSoup](https://www.crummy.com/software/BeautifulSoup/bs4/doc/) parsed objects.

 
## The api documentation can be found at:
[bs-processors documentation](https://raduw.github.io/bs-processors/)
